==> alfred_osint-0.2.3.dev0-py3-none-any.whl: alfred_osint/lang/es.py <==
# es.py
# Español

encrypt1 = "Cifrando Clave..."

title1 = "¡Muchas gracias a nuestros socios!"

disclamer = "     Descargo de responsabilidad: ¡No se garantiza que todos los sitios o proxies funcionen! \n     Al usar, asume toda la responsabilidad de sus acciones"

targetusernames = "Los nombres de usuario de destino:"

version = "Versión"

config1 = "Existe archivo de configuración:"
config2 = "Existe archivo de actualización:"
config3 = "La carpeta ya existe:"
config4 = "¿Buscar actualizaciones? [Y/n]: ⤷ "
config5 = "¿Editar la configuración? [Y/n]: ⤷ "
config6 = "¿Qué quieres cambiar? ⤷ "
config7 = "Creando carpeta:"
config8 = "La carpeta ya existe:"

configOption1 = "[1] Buscar actualizaciones: "
configOption2 = "[2] Mostrar consejos: "
configOption3 = "[3] Ruta de descarga del sitio: "
configOption4 = "[4] Navegador: "
configOption5 = "[5] Idioma: "
configOptionA = "[A] Limpiar Alfred. (Esto elimina archivos temporales)"
configOptionB = "[B] Herramientas de desarrollo."

configOption1Message = "¡Ok! [checkforupdates] está configurado en Sí. Cambiando a No"
configOption2Message = "¡Ok! [showtips] está configurado en Sí. Cambiando a No"
configOption3Message = "Nueva ruta: ⤷ "
configOption4Message = """Tipos compatibles:
                         Firefox
                         Edge
                         Chrome
                         """
configOption5Message = """
            indique su código de idioma
            Idioma compatible:
                it = italiano
                en = inglés
                il = hebreo 
                es = español
                fr = francés 
                ar = árabe
                         """
configOptionAMessage = "Hecho!"
configOptionBMessage = "¡Bienvenido al menú de desarrolladores!"

configOption1Message2 = "¡Ok! [checkforupdates] está configurado en No. Cambiando a Sí"
configOption2Message2 = "¡Ok! [showtips] está configurado en No. Cambiando a Sí"
configOptionBMessage2 = (
    "NO proporcione las siguientes claves a nadie que no sea un desarrollador de Alfred"
)
configOptionBMessage3 = "claveprivada: "
configOptionBMessage4 = "syscrypt: "

target = "Objetivo: ⤷ "
browser = "Navegador: "

file_not_found = "Archivo no encontrado: {filename}"
permission_denied = "Permiso denegado para {operation} en {path}"

note = "¡Nota! "
path = "RUTA: ⤷ "
warning1 = "Es posible que los sitios no permitan la descarga de los archivos de su sitio. Úselo bajo su propio riesgo."
warning2 = "El uso del web scraper es bastante lento"
warning3 = "Este es tu primer lanzamiento :D Es posible que debas reiniciar Alfred para usar todos los módulos"
warning4 = "¡Estás usando una versión preliminar de Alfred!"

confirm1 = "¿Desea descargar imágenes/videos? [Y/n] ⤷ "
confirm2 = "¿Ejecutar de nuevo? [Y/n] ⤷ "

prompt1 = "Vuelve a ingresar el sitio: ⤷ "
prompt2 = "Por favor, informe cualquier error o bug a nuestro repositorio o servidor de Discord. "
prompt3 = "Puede deshabilitar la actualización en el archivo de configuración"
prompt4 = "Únase a nuestro Discord: https://discord.gg/xrdjxyuSQt "
prompt5 = "¡Ok! Lo preguntaré más tarde..."
prompt6 = "Sitios que no funcionan..."

download1 = "Descargando "
updates = "¡Las actualizaciones están habilitadas!"


idk1 = "No estoy seguro de qué quieres decir..."
idk2 = "No estoy seguro de qué quieres decir. Lo preguntaré más tarde"
idk3 = "No estoy seguro... pero puedes consultar aquí: "
scan1 = "buscando sitios con: "

status1 = "Trabajando..."
status2 = "Creando / sobrescribiendo archivo guardado."
status3 = "Reinstalando............"
status4 = "Regresando a Alfred pronto..."
status5 = "Probando....."
status6 = "Deteniendo..... Guardado en capturado/trabajando.txt"
status7 = "Deteniendo........"

save1 = "Resultados guardados en"
save2 = "Resultados guardados en archivo"

error1 = "Error de permiso"
error2 = "Error de tipo"
error3 = "¡No puedo encontrar el archivo guardado!"
error4 = "El directorio no existe."
error5 = "No se pueden encontrar los archivos necesarios. Se intenta reinstalar Alfred."
error6 = "¡Error de Uh Oh! Parece que la conexión no parece funcionar. Revise su conexión o proxy, luego intente nuevamente:"
error7 = "No se puede encontrar el archivo del sitio"
error8 = "¡Error al descargar contenido web!"
error9 = "Error con el archivo del sitio"
error10 = "Selección de webdriver no válida."
error11 = "Ocurrió un error:"

fileshare1 = "[*] Escuchando como"
fileshare2 = "está conectado."
fileshare3 = "Recibiendo"

wikiOption1 = "[1] Instalación"
wikiOption2 = "[2] Opciones"
wikiOption3 = "[3] Errores"
wikiOption4 = "[4] Alfred oscuro"
wikiOption5 = "[5] Módulos"

wikilist = "Puede encontrar información al respecto aquí: "

rqUname = "Usuario solicitado: "

sender1 = "[+] Conectando a"
sender2 = "[+] Conectado."
sender3 = "Envío."
sender4 = "Archivo para enviar: ⤷ "

fs1 = "¿Servidor host? [Y/N]: ⤷ "
fs2 = "¡Esperando para conectarse al host!"
fs3 = "¡Esperando que se conecte el cliente!"

siteDl1 = "Total de archivos de script en la página:"
siteDl2 = "Total de archivos CSS en la página:"

==> alfred_osint-0.2.3.1-py3-none-any.whl: alfred_osint/lang/es.py <==
# es.py
# Español

encrypt1 = "Cifrando Clave..."

title1 = "¡Muchas gracias a nuestros socios!"

disclamer = "     Descargo de responsabilidad: ¡No se garantiza que todos los sitios o proxies funcionen! \n     Al usar, asume toda la responsabilidad de sus acciones"

targetusernames = "Los nombres de usuario de destino:"

version = "Versión"

config1 = "Existe archivo de configuración"
config2 = "Existe archivo de actualización"
config3 = "La carpeta ya existe:"
config4 = "¿Buscar actualizaciones? [Y/n]: ⤷ "
config5 = "¿Editar la configuración? [Y/n]: ⤷ "
config6 = "¿Qué quieres cambiar? ⤷ "
config7 = "Creando carpeta:"
config8 = "La carpeta ya existe:"

configOption1 = "[1] Buscar actualizaciones: "
configOption2 = "[2] Mostrar consejos: "
configOption3 = "[3] Ruta de descarga del sitio: "
configOption4 = "[4] Navegador: "
configOption5 = "[5] Idioma: "
configOptionA = "[A] Limpiar Alfred. (Esto elimina archivos temporales)"
configOptionB = "[B] Herramientas de desarrollo."

configOption1Message = "¡Ok! [checkforupdates] está configurado en Sí. Cambiando a No"
configOption2Message = "¡Ok! [showtips] está configurado en Sí. Cambiando a No"
configOption3Message = "Nueva ruta: ⤷ "
configOption4Message = """Tipos compatibles:
                         Firefox
                         Edge
                         Chrome
                         """
configOption5Message = """
            indique su código de idioma
            Idioma compatible:
                it = italiano
                en = inglés
                il = hebreo 
                es = español
                fr = francés 
                ar = árabe
                de = alemán
                         """
configOptionAMessage = "Hecho!"
configOptionBMessage = "¡Bienvenido al menú de desarrolladores!"

configOption1Message2 = "¡Ok! [checkforupdates] está configurado en No. Cambiando a Sí"
configOption2Message2 = "¡Ok! [showtips] está configurado en No. Cambiando a Sí"
configOptionBMessage2 = (
    "NO proporcione las siguientes claves a nadie que no sea un desarrollador de Alfred"
)
configOptionBMessage3 = "claveprivada: "
configOptionBMessage4 = "syscrypt: "

target = "Objetivo: ⤷ "
browser = "Navegador: "

file_not_found = "Archivo no encontrado: {filename}"
permission_denied = "Permiso denegado para {operation} en {path}"

note = "¡Nota! "
path = "RUTA: ⤷ "
warning1 = "Es posible que los sitios no permitan la descarga de los archivos de su sitio. Úselo bajo su propio riesgo."
warning2 = "El uso del web scraper es bastante lento"
warning3 = "Este es tu primer lanzamiento :D Es posible que debas reiniciar Alfred para usar todos los módulos"
warning4 = "¡Estás usando una versión preliminar de Alfred!"

confirm1 = "¿Desea descargar imágenes/videos? [Y/n] ⤷ "
confirm2 = "¿Ejecutar de nuevo? [Y/n] ⤷ "

prompt1 = "Vuelve a ingresar el sitio: ⤷ "
prompt2 = "Por favor, informe cualquier error o bug a nuestro repositorio o servidor de Discord. "
prompt3 = "Puede deshabilitar la actualización en el archivo de configuración"
prompt4 = "Únase a nuestro Discord: https://discord.gg/xrdjxyuSQt "
prompt5 = "¡Ok! Lo preguntaré más tarde..."
prompt6 = "Sitios que no funcionan..."

download1 = "Descargando "
updates = "¡Las actualizaciones están habilitadas!"


idk1 = "No estoy seguro de qué quieres decir..."
idk2 = "No estoy seguro de qué quieres decir. Lo preguntaré más tarde"
idk3 = "No estoy seguro... pero puedes consultar aquí: "
scan1 = "buscando sitios con: "

status1 = "Trabajando..."
status2 = "Creando / sobrescribiendo archivo guardado."
status3 = "Reinstalando............"
status4 = "Regresando a Alfred pronto..."
status5 = "Probando....."
status6 = "Deteniendo..... Guardado en capturado/trabajando.txt"
status7 = "Deteniendo........"

save1 = "Resultados guardados en"
save2 = "Resultados guardados en archivo"

error1 = "Error de permiso"
error2 = "Error de tipo"
error3 = "¡No puedo encontrar el archivo guardado!"
error4 = "El directorio no existe."
error5 = "No se pueden encontrar los archivos necesarios. Se intenta reinstalar Alfred."
error6 = "¡Error de Uh Oh! Parece que la conexión no parece funcionar. Revise su conexión o proxy, luego intente nuevamente:"
error7 = "No se puede encontrar el archivo del sitio"
error8 = "¡Error al descargar contenido web!"
error9 = "Error con el archivo del sitio"
error10 = "Selección de webdriver no válida."
error11 = "Ocurrió un error:"

fileshare1 = "[*] Escuchando como"
fileshare2 = "está conectado."
fileshare3 = "Recibiendo"

wikiOption1 = "[1] Instalación"
wikiOption2 = "[2] Opciones"
wikiOption3 = "[3] Errores"
wikiOption4 = "[4] Alfred oscuro"
wikiOption5 = "[5] Módulos"

wikilist = "Puede encontrar información al respecto aquí: "

rqUname = "Usuario solicitado: "

sender1 = "[+] Conectando a"
sender2 = "[+] Conectado."
sender3 = "Envío."
sender4 = "Archivo para enviar: ⤷ "

fs1 = "¿Servidor host? [Y/N]: ⤷ "
fs2 = "¡Esperando para conectarse al host!"
fs3 = "¡Esperando que se conecte el cliente!"

siteDl1 = "Total de archivos de script en la página:"
siteDl2 = "Total de archivos CSS en la página:"
